@@ -19,7 +19,7 @@ from collections import OrderedDict
 from astropy.wcs import FITSFixedWarning
 
 # Set the Marvin version
-__version__ = '2.3.5'
+__version__ = '2.4.1'
 
 # Does this so that the implicit module definitions in extern can happen.
 # time - 483 ms
@@ -210,7 +210,7 @@ class MarvinConfig(object):
         self._checkPaths('MANGA_SPECTRO_REDUX')
         self._checkPaths('MANGA_SPECTRO_ANALYSIS')
 
-    def setDefaultDrpAll(self, drpver=None):
+    def setDefaultDrpAll(self, drpver=None, dapver=None):
         """Tries to set the default location of drpall.
 
         Sets the drpall attribute to the location of your DRPall file, based on the
@@ -222,18 +222,33 @@ class MarvinConfig(object):
                 The DRP version to set.  Defaults to the version corresponding to config.release.
         """
 
-        if not drpver:
-            drpver, __ = self.lookUpVersions(self.release)
+        if not drpver or not dapver:
+            drpver, dapver = self.lookUpVersions(self.release)
         self.drpall = self._getDrpAllPath(drpver)
+        self.dapall = self._getDapAllPath(drpver, dapver)
+
+    def _get_default_path(self, name, drpver, dapver=None):
+        ''' Return a default path to a summary file '''
+        assert name in ['drpall', 'dapall'], 'name must be either drpall or dapall'
+        envvar = 'MANGA_SPECTRO_REDUX' if name == 'drpall' else 'MANGA_SPECTRO_ANALYSIS'
+        version = drpver if name == 'drpall' else dapver
+        if name == 'drpall':
+            path = os.path.join(str(drpver), 'drpall-{0}.fits'.format(version))
+        elif name == 'dapall':
+            path = os.path.join(str(drpver), str(dapver), 'dapall-{0}-{1}.fits'.format(drpver, dapver))
+
+        if envvar in os.environ and version:
+            return os.path.join(os.environ[envvar], path)
+        else:
+            raise MarvinError('Must have the {0} environment variable set'.format(envvar))
 
     def _getDrpAllPath(self, drpver):
         """Returns the default path for drpall, give a certain ``drpver``."""
+        return self._get_default_path('drpall', drpver)
 
-        if 'MANGA_SPECTRO_REDUX' in os.environ and drpver:
-            return os.path.join(os.environ['MANGA_SPECTRO_REDUX'], str(drpver),
-                                'drpall-{0}.fits'.format(drpver))
-        else:
-            raise MarvinError('Must have the MANGA_SPECTRO_REDUX environment variable set')
+    def _getDapAllPath(self, drpver, dapver):
+        """Returns the default path for dapall, give a certain ``drpver, dapver``."""
+        return self._get_default_path('dapall', drpver, dapver=dapver)
 
 ############ Brain Config overrides ############
 # These are configuration parameter defined in Brain.bconfig. We need
@@ -271,10 +286,13 @@ class MarvinConfig(object):
         with self._replant_tree(value) as val:
             self._release = val
 
+        drpver, dapver = self.lookUpVersions(value)
         if 'MANGA_SPECTRO_REDUX' in os.environ:
-            drpver, __ = self.lookUpVersions(value)
             self.drpall = self._getDrpAllPath(drpver)
 
+        if 'MANGA_SPECTRO_ANALYSIS' in os.environ:
+            self.dapall = self._getDapAllPath(drpver, dapver)
+
     @property
     def access(self):
         return bconfig.access
@@ -369,6 +387,19 @@ class MarvinConfig(object):
             warnings.warn('path {0} cannot be found. Setting drpall to None.'
                           .format(value), MarvinUserWarning)
 
+    @property
+    def dapall(self):
+        return self._dapall
+
+    @dapall.setter
+    def dapall(self, value):
+        if os.path.exists(value):
+            self._dapall = value
+        else:
+            self._dapall = None
+            warnings.warn('path {0} cannot be found. Setting dapall to None.'
+                          .format(value), MarvinUserWarning)
+
     def _setDbConfig(self):
         ''' Set the db configuration '''
         self.db = getDbMachine()
@@ -492,19 +523,25 @@ class MarvinConfig(object):
 
         return drpver, dapver
 
-    def lookUpRelease(self, drpver):
+    def lookUpRelease(self, drpver, public_only=None):
         """Retrieve the release version for a given DRP version
 
         Parameters:
             drpver (str):
                 The DRP version to use
+            public_only (bool):
+                If True, uses only DR releases
         Returns:
             release (str):
                 The release version according to the input DRP version
         """
 
         # Flip the mpldict
-        verdict = {val[0]: key for key, val in self._allowed_releases.items()}
+        verdict = {}
+        for key, val in self._allowed_releases.items():
+            if (public_only and 'MPL' in key):
+                continue
+            verdict[val[0]] = key
 
         try:
             release = verdict[drpver]
@@ -524,7 +561,7 @@ class MarvinConfig(object):
         use localhost.
 
         Parameters:
-            sasmode ({'utah', 'local'}):
+            sasmode ({'utah', 'local', 'mirror'}):
                 the SAS mode to switch to.  Default is Utah
             ngrokid (str):
                 The ngrok id to use when using a 'localhost' sas mode.
@@ -538,7 +575,7 @@ class MarvinConfig(object):
             public (bool):
                 If ``True``, sets the API url to the public domain
         '''
-        assert sasmode in ['utah', 'local'], 'SAS mode can only be utah or local'
+        assert sasmode in ['utah', 'local', 'mirror'], 'SAS mode can only be utah, local, or mirror'
         base = base if base else os.environ.get('MARVIN_BASE', 'marvin')
         test_domain = 'https://lore.sdss.utah.edu/'
         if sasmode == 'local':
@@ -562,17 +599,8 @@ class MarvinConfig(object):
 
             # get a new urlmap (need to do for vetting)
             self._urlmap = None
-            #__ = self.urlmap
-
-            # marvin_base = 'test/{0}/'.format(base) if test else '{0}/'.format(base)
-            # if public:
-            #     base_url = re.sub(r'(dr[0-9]{1,2})', self._release.lower(), bconfig.public_api_url)
-            #     public_api = os.path.join(base_url, marvin_base)
-            #     self.sasurl = public_api
-            #     self._authtype = None
-            # else:
-            #     self.sasurl = os.path.join(bconfig.collab_api_url, marvin_base)
-            #     self._authtype = 'token'
+        elif sasmode == 'mirror':
+            self.sasurl = bconfig.mirror_api_url
 
     def forceDbOff(self):
         ''' Force the database to be turned off '''
@@ -687,6 +715,11 @@ class MarvinConfig(object):
         elif 'DR' in value:
             self.switchSasUrl('utah', public=True)
 
+        # check to use the SAS mirror
+        mirror = self._custom_config.get('use_mirror', None)
+        if mirror:
+            self.switchSasUrl('mirror', public='DR' in value)
+
     def login(self, refresh=None):
         ''' Login with netrc credentials to receive an API token
 
